/* ************************************************************** grab.h *** *
 * Υ إåե
 *
 * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                  Time-stamp: <03/05/02 23:16:59 sugaya>
 * ************************************************************************* */
#ifndef	__GRAB_H__
#define	__GRAB_H__

void	grab_do_grab		(void);

#endif	/* __GRAB_H__ */

/* ******************************************************* End of grab.h *** */
